==> mob_variants_api_zenxarch-0.0.1-sources.jar: org/codeberg/zenxarch/mob_variants_api/variant/effect/single/AttributeModifierEffect.java <==
package org.codeberg.zenxarch.mob_variants_api.variant.effect.single;

import com.mojang.serialization.Codec;
import com.mojang.serialization.MapCodec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import java.util.List;
import net.minecraft.class_1309;
import net.minecraft.class_1320;
import net.minecraft.class_1322;
import net.minecraft.class_3218;
import net.minecraft.class_5699;
import net.minecraft.class_6880;
import org.codeberg.zenxarch.mob_variants_api.variant.effect.LivingEffect;

public record AttributeModifierEffect(
    class_6880<class_1320> attribute,
    List<class_1322> modifiers,
    boolean persistent)
    implements LivingEffect {
  public static final MapCodec<AttributeModifierEffect> CODEC =
      RecordCodecBuilder.mapCodec(
          instance ->
              instance
                  .group(
                      class_1320.field_51575
                          .fieldOf("attribute")
                          .forGetter(AttributeModifierEffect::attribute),
                      class_5699.method_65313(class_1322.field_46247)
                          .fieldOf("modifiers")
                          .forGetter(AttributeModifierEffect::modifiers),
                      Codec.BOOL
                          .optionalFieldOf("persistent", true)
                          .forGetter(AttributeModifierEffect::persistent))
                  .apply(instance, AttributeModifierEffect::new));

  @Override
  public void run(class_3218 world, class_1309 target) {
    var instance = target.method_5996(attribute);
    if (persistent) instance.method_61434(modifiers);
    else modifiers.forEach(instance::method_26835);
  }

  @Override
  public MapCodec<? extends LivingEffect> getCodec() {
    return CODEC;
  }
}

==> mob_variants_api_zenxarch-0.0.2-sources.jar: org/codeberg/zenxarch/mob_variants_api/variant/effect/single/AttributeModifierEffect.java <==
package org.codeberg.zenxarch.mob_variants_api.variant.effect.single;

import com.mojang.serialization.Codec;
import com.mojang.serialization.MapCodec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import java.util.List;
import net.minecraft.class_1309;
import net.minecraft.class_1320;
import net.minecraft.class_1322;
import net.minecraft.class_1324;
import net.minecraft.class_3218;
import net.minecraft.class_5699;
import net.minecraft.class_6880;
import org.codeberg.zenxarch.mob_variants_api.variant.effect.LivingEffect;

public record AttributeModifierEffect(
    class_6880<class_1320> attribute,
    List<class_1322> modifiers,
    boolean persistent)
    implements LivingEffect {
  public static final MapCodec<AttributeModifierEffect> CODEC =
      RecordCodecBuilder.mapCodec(
          instance ->
              instance
                  .group(
                      class_1320.field_51575
                          .fieldOf("attribute")
                          .forGetter(AttributeModifierEffect::attribute),
                      class_5699.method_65313(class_1322.field_46247)
                          .fieldOf("modifiers")
                          .forGetter(AttributeModifierEffect::modifiers),
                      Codec.BOOL
                          .optionalFieldOf("persistent", true)
                          .forGetter(AttributeModifierEffect::persistent))
                  .apply(instance, AttributeModifierEffect::new));

  @Override
  public void run(class_3218 world, class_1309 target) {
    var instance = target.method_5996(attribute);
    if (instance == null) return;
    modifiers.forEach(modifier -> addModifier(instance, modifier));
  }

  private void addModifier(class_1324 instance, class_1322 modifier) {
    if (instance.method_6196(modifier.comp_2447())) return;
    if (persistent) instance.method_26837(modifier);
    else instance.method_26835(modifier);
  }

  @Override
  public MapCodec<? extends LivingEffect> getCodec() {
    return CODEC;
  }
}
